==> homematic-manager-1.0.4.tgz: package/www/js/language.js <==
var translation = {
    "Error":            {"de": "Fehler"},
    "Devices":          {"de": "Geräte"},
    "Events":           {"de": "Ereignisse"},
    "Cancel":           {"de": "Abbrechen"},
    "OK":               {"de": "OK"},
    "Delete":           {"de": "Löschen"},
    "Save":             {"de": "Speichern"},
    "Create and edit":  {"de": "Anlegen und Bearbeiten"},
    "Create":           {"de": "Anlegen"},
    "Please choose one or more channels":        {"de": "Bitte einen oder mehere Kanäle auswählen"},
    "Refresh":          {"de": "Aktualisieren"},
    "Delete device":    {"de": "Gerät löschen"},
    "Rename device":    {"de": "Gerät umbenennen"},
    "Pair devices":     {"de": "Geräte anlernen"},
    "Links":            {"de": "Verknüpfungen"},
    "Delete link":     {"de": "Verknüpfung löschen"},
    "Edit link":       {"de": "Verknüpfung bearbeiten"},
    "Test link":        {"de": "Verknüpfung testen"},
    "Create link":      {"de": "Verknüpfung anlegen"},
    "RSSI":             {"de": "Funk"},
    "RPC Console":      {"de": "RPC Konsole"},
    "Service messages": {"de": "Servicemeldungen"},
    "Send request":     {"de": "Befehl senden"},
    "Parameters":       {"de": "Parameter"},
    "Response":         {"de": "Antwort"},
    "Help":             {"de": "Hilfe"},
    "Settings":         {"de": "Einstellungen"},
    "Acknowledge service messages":         {"de": "Servicemeldung bestätigen"},
    "Acknowledge all service messages":     {"de": "Alle Servicemeldungen bestätigen"},
    "Interfaces":       {"de": "Interfaces"},
    "Edit device":      {"de": "Gerät bearbeiten"},
    "undefined":        {"de": "undefined"},
    "Please select method":                 {"de": "Bitte eine Methode auswählen"},
    "saveAsNewTemplate":{"de":"als neue Profilvorlage speichern","en":"saveAsNewTemplate"},
    "Replace device":{"de":"Gerät tauschen","en":"Replace device"},
    "Update firmware":{"de":"Firmware aktualisieren","en":"Update firmware"},
    "clearConfigCache":{"de":"clearConfigCache","en":"clearConfigCache"},
    "restoreConfigToDevice":{"de":"restoreConfigToDevice","en":"restoreConfigToDevice"},
    "Rename":{"de":"Umbenennen","en":"Rename"},
    "MASTER Paramset":{"de":"MASTER Paramset","en":"MASTER Paramset"},
    "updateFirmware":{"de":"Firmware aktualisieren","en":"updateFirmware"},
    "Replace":{"de":"Gerät tauschen","en":"Replace"},
    "VALUES Paramset":{"de":"VALUES Paramset","en":"VALUES Paramset"},
    "Activate long": {"de": "Empfägnerprofil testen (langer Tastendruck)", "en": "Activate long"},
    "Activate short":        {"de": "Empfängerprofil testen (kurzer Tastendruck)", "en": "Activate short"},
    "putParamset":        {"de": "Parameter in Gerät übernehmen", "en": "putParamset"},
    "New service message": {"de": "Neue Servicemeldung", "en":"New service message"},
    "RPC execution": {"de": "RPC wird ausgeführt", "en": "RPC execution"},
    "about HomeMatic Manager": {"de": "Über HomeMatic Manager", "en": "about HomeMatic Manager"},
    "Loading HomeMatic Manager...": {"de": "Lade HomeMatic Manager...", "en": "Loading HomeMatic Manager..."},
    "Check all": {"de": "Alle auswählen", "en": "Check all"},
    "Uncheck all": {"de": "Auswahl entfernen", "en": "Uncheck all"}
};



var missesTranslation = {};

==> homematic-manager-1.0.9.tgz: package/www/js/language.js <==
var translation = {
    "Error":            {"de": "Fehler"},
    "Devices":          {"de": "Geräte"},
    "Events":           {"de": "Ereignisse"},
    "Cancel":           {"de": "Abbrechen"},
    "OK":               {"de": "OK"},
    "Delete":           {"de": "Löschen"},
    "Save":             {"de": "Speichern"},
    "Create and edit":  {"de": "Anlegen und Bearbeiten"},
    "Create":           {"de": "Anlegen"},
    "Please choose one or more channels":        {"de": "Bitte einen oder mehrere Kanäle auswählen"},
    "Refresh":          {"de": "Aktualisieren"},
    "Delete device":    {"de": "Gerät löschen"},
    "Rename device":    {"de": "Gerät umbenennen"},
    "Pair devices":     {"de": "Geräte anlernen"},
    "Links":            {"de": "Verknüpfungen"},
    "Delete link":     {"de": "Verknüpfung löschen"},
    "Edit link":       {"de": "Verknüpfung bearbeiten"},
    "Test link":        {"de": "Verknüpfung testen"},
    "Create link":      {"de": "Verknüpfung anlegen"},
    "RSSI":             {"de": "Funk"},
    "RPC Console":      {"de": "RPC Konsole"},
    "Service messages": {"de": "Servicemeldungen"},
    "Send request":     {"de": "Befehl senden"},
    "Parameters":       {"de": "Parameter"},
    "Response":         {"de": "Antwort"},
    "Help":             {"de": "Hilfe"},
    "Settings":         {"de": "Einstellungen"},
    "Acknowledge service messages":         {"de": "Servicemeldung bestätigen"},
    "Acknowledge all service messages":     {"de": "Alle Servicemeldungen bestätigen"},
    "Interfaces":       {"de": "Interfaces"},
    "Edit device":      {"de": "Gerät bearbeiten"},
    "undefined":        {"de": "undefined"},
    "Please select method":                 {"de": "Bitte eine Methode auswählen"},
    "saveAsNewTemplate":{"de":"als neue Profilvorlage speichern","en":"saveAsNewTemplate"},
    "Replace device":{"de":"Gerät tauschen","en":"Replace device"},
    "Update firmware":{"de":"Firmware aktualisieren","en":"Update firmware"},
    "clearConfigCache":{"de":"clearConfigCache","en":"clearConfigCache"},
    "restoreConfigToDevice":{"de":"restoreConfigToDevice","en":"restoreConfigToDevice"},
    "Rename":{"de":"Umbenennen","en":"Rename"},
    "MASTER Paramset":{"de":"MASTER Paramset","en":"MASTER Paramset"},
    "updateFirmware":{"de":"Firmware aktualisieren","en":"updateFirmware"},
    "Replace":{"de":"Gerät tauschen","en":"Replace"},
    "VALUES Paramset":{"de":"VALUES Paramset","en":"VALUES Paramset"},
    "Activate long": {"de": "Empfägnerprofil testen (langer Tastendruck)", "en": "Activate long"},
    "Activate short":        {"de": "Empfängerprofil testen (kurzer Tastendruck)", "en": "Activate short"},
    "putParamset":        {"de": "Parameter in Gerät übernehmen", "en": "putParamset"},
    "New service message": {"de": "Neue Servicemeldung", "en":"New service message"},
    "RPC execution": {"de": "RPC wird ausgeführt", "en": "RPC execution"},
    "about HomeMatic Manager": {"de": "Über HomeMatic Manager", "en": "about HomeMatic Manager"},
    "Loading HomeMatic Manager...": {"de": "Lade HomeMatic Manager...", "en": "Loading HomeMatic Manager..."},
    "Check all": {"de": "Alle auswählen", "en": "Check all"},
    "Uncheck all": {"de": "Auswahl entfernen", "en": "Uncheck all"}
};



var missesTranslation = {};
